import { Autocomplete, Box, CircularProgress, Paper, TextField, Typography } from "@mui/material"
import { useBoilers, useRegions, useServers } from "../hooks/swrHooks"
import { Fragment, useEffect, useState } from "react"
import { IBoiler, IRegion } from "../interfaces/fuel"
import { DataGrid, GridColDef } from "@mui/x-data-grid"

export default function ApiTest() {
    const [open, setOpen] = useState(false)
    const [options, setOptions] = useState<IRegion[]>([])
    const [search, setSearch] = useState<string | null>(null)
    const [debouncedSearch, setDebouncedSearch] = useState<string | null>("")
    const [selectedOption, setSelectedOption] = useState<IRegion | null>(null)
    const { regions, isLoading } = useRegions(10, 1, debouncedSearch)

    useEffect(() => {
        const handler = setTimeout(() => {
            setDebouncedSearch(search)
        }, 500)

        return () => {
            clearTimeout(handler)
        }
    }, [search])

    useEffect(() => {
        if (regions) {
            setOptions([...regions])
        }
    }, [regions])

    const handleInputChange = (value: string) => {
        setSearch(value)
    }

    const handleOptionChange = (value: IRegion | null) => {
        setSelectedOption(value)
    }

    const [boilersPage, setBoilersPage] = useState(1)
    const [boilerSearch, setBoilerSearch] = useState("")
    const [debouncedBoilerSearch, setDebouncedBoilerSearch] = useState("")
    const { boilers } = useBoilers(10, boilersPage, debouncedBoilerSearch)

    useEffect(() => {
        const handler = setTimeout(() => {
            setDebouncedBoilerSearch(boilerSearch)
        }, 500)

        return () => {
            clearTimeout(handler)
        }
    }, [boilerSearch])

    useEffect(() => {
        setBoilersPage(1)
        setBoilerSearch("")
    }, [])

    //const { cities } = useCities(10, 1)
    const { servers, isLoading: serversLoading } = useServers(selectedOption?.id, 0, 10)

    const serversColumns: GridColDef[] = [
        { field: 'id', headerName: 'ID', type: "number" },
        { field: 'name', headerName: 'Название', type: "string" },
    ]

    const boilersColumns: GridColDef[] = [
        { field: 'id', headerName: 'ID', type: "number" },
        { field: 'boiler_name', headerName: 'Название', type: "string" },
        { field: 'boiler_code', headerName: 'Код', type: "string" },
        { field: 'id_city', headerName: 'Город', type: "string" },
        { field: 'activity', headerName: 'Активен', type: "boolean" },
    ]

    return (
        <Box sx={{ display: 'flex', flexDirection: 'column', gap: '16px', height: '100%' }}>
            <Paper elevation={1}>
                <Box sx={{ display: 'flex', flexDirection: 'column', gap: '16px', height: '100%', p: '16px' }}>
                    <Typography variant='h6' fontWeight='600'>
                        Servers
                    </Typography>

                    <Autocomplete
                        open={open}
                        onOpen={() => {
                            setOpen(true)
                        }}
                        onClose={() => {
                            setOpen(false)
                        }}
                        onInputChange={(_, value) => handleInputChange(value)}
                        onChange={(_, value) => handleOptionChange(value)}
                        filterOptions={(x) => x}
                        isOptionEqualToValue={(option: IRegion, value: IRegion) => option.name === value.name}
                        getOptionLabel={(option: IRegion) => option.name ? option.name : ""}
                        options={options}
                        loading={isLoading}
                        value={selectedOption}
                        renderInput={(params) => (
                            <TextField
                                {...params}
                                label="Район"
                                InputProps={{
                                    ...params.InputProps,
                                    endAdornment: (
                                        <Fragment>
                                            {isLoading ? <CircularProgress color="inherit" size={20} /> : null}
                                            {params.InputProps.endAdornment}
                                        </Fragment>
                                    )
                                }}
                            />
                        )}
                    />

                    {serversLoading ?
                        <CircularProgress />
                        :
                        servers &&
                        <DataGrid
                            rowSelection={false}
                            rows={servers}
                            columns={serversColumns}
                        />
                    }
                </Box>
            </Paper>

            <Paper elevation={1}>
                <Box sx={{ display: 'flex', flexDirection: 'column', gap: '16px', height: '100%', p: '16px' }}>
                    <Typography variant='h6' fontWeight='600'>
                        Boilers
                    </Typography>

                    {boilers &&
                        <DataGrid
                            rows={boilers.map((boiler: IBoiler) => {
                                return { ...boiler, id: boiler.id_object }
                            })}
                            columns={boilersColumns}
                        />
                    }

                </Box>
            </Paper>
        </Box>
    )
}